const attr = require('dynamodb-data-types').AttributeValue;

const getAction = (record) => {
  const SUPPORTED_ACTIONS = ['INSERT', 'MODIFY', 'REMOVE'];
  if (!(record && record.eventName)) {
    throw new Error('VALIDATION: Invalid record. "record.eventName" is missing.');
  }
  if (SUPPORTED_ACTIONS.indexOf(record.eventName) === -1) {
    throw new Error(`VALIDATION: Invalid record. "record.eventName" is not supported. Rrcived: ${record.eventName}`);
  }
  return record.eventName;
};

const parseKeys = (record) => {
  if (!(record && record.dynamodb && record.dynamodb.Keys)) {
    throw new Error('VALIDATION: Invalid record. "record.dynamodb.Keys" is missing.');
  }
  return attr.unwrap(record.dynamodb.Keys);
};

const getDoc = (record, action) => {
  if (action === 'REMOVE') {
    return null;
  }
  if (!(record && record.dynamodb && record.dynamodb.NewImage)) {
    throw new Error('VALIDATION: Invalid record. "record.dynamodb.NewImage" is missing.');
  }
  return attr.unwrap(record.dynamodb.NewImage);
};

module.exports = {
  getAction,
  parseKeys,
  getDoc,
};
