const parser = require('./parser');
const es = require('./es');
const R = require('ramda');

const createIdFromKeys = keys => Object.keys(keys).map(key => keys[key]).sort().join('#');

const isRecordsIsArray = event => R.propSatisfies(Array.isArray, 'Records', event);

module.exports = config => (event) => {
  console.log('event: ', JSON.stringify(event, null, 4));
  if (!isRecordsIsArray(event)) {
    throw new Error('event.Records should be the valid array of records produced by DynamoDB stream.');
  }
  if (event.Records.length === 0) {
    return Promise.resolve([]);
  }

  const { index, type, createIndexIfNeeded = true } = config;
  if (!index) {
    throw new Error('"config.index" should be specified.');
  }
  if (!type) {
    throw new Error('"config.type" should be specified.');
  }

  return es({
    index,
    type,
    createIndexIfNeeded,
  })
    .then(handlers => Promise.all(event.Records.map((record) => {
      const action = parser.getAction(record);
      const doc = parser.getDoc(record, action);
      const keys = parser.parseKeys(record);
      const id = createIdFromKeys(keys);

      return handlers[action](id, doc)
        .then(response => {
          console.log(`${action} performed. Doc id: ${id}`);
          return response;
        })
        .catch(error => {
          console.log(`Performing ${action} ended up with error ${error}`);
          throw new Error(error);
        });
    })));
};
